# Cybernetics

[![Build Status](https://travis-ci.org/wol4aravio/Cybernetics.svg?branch=master)](https://travis-ci.org/wol4aravio/Cybernetics)
[![PyPI version](https://badge.fury.io/py/cybernetics.svg)](https://badge.fury.io/py/cybernetics)
[![Maintainability](https://api.codeclimate.com/v1/badges/2fe2cb9b904db2fea38c/maintainability)](https://codeclimate.com/github/wol4aravio/Cybernetics/maintainability)
[![Test Coverage](https://api.codeclimate.com/v1/badges/2fe2cb9b904db2fea38c/test_coverage)](https://codeclimate.com/github/wol4aravio/Cybernetics/test_coverage)